skhubness.reduction.MutualProximity — scikit-hubness 0.21a1 documentation

# skhubness.reduction.MutualProximity

class `skhubness.reduction.` `MutualProximity`(k: int = 5, method: str = 'normal', verbose: int = 0)

  Hubness reduction with Mutual Proximity.

  `__init__`(self, k: 'int' = 5, method: 'str' = 'normal', verbose: 'int' = 0)

    Initialize self. See help(type(self)) for accurate signature.

  Methods

  `__init__`(self, k, method, verbose) | Initialize self.
  `fit`(self, neigh_dist, neigh_ind, \*args, …) |
  `transform`(self, neigh_dist, neigh_ind, …) |